@@ -6,6 +6,10 @@ import numpy as np
 from scipy.interpolate import interp1d
 from . import sobol as sbl
 
+from twiggy import quick_setup,log
+quick_setup()
+logger = log.name('hfns')
+
 
 def ecdf(x_):
     """
