@@ -4,6 +4,11 @@ from scipy.special import factorial
 from . import helperfunctions as hfns
 from . import distributions as distributions
 
+from twiggy import quick_setup,log
+quick_setup()
+logger = log.name('lossaggregation')
+
+
 class LossAggregation:
     """
         This class computes the probability that the sum of random variables
