@@ -4,6 +4,11 @@ from scipy.fft import fft, ifft
 from . import helperfunctions as hfns
 from . import distributions as distributions
 
+from twiggy import quick_setup,log
+quick_setup()
+logger = log.name('lossmodel')
+
+
 ## Actual
 class Frequency:
     """
