@@ -4,6 +4,10 @@ from scipy import stats
 import matplotlib.pyplot as plt
 from . import helperfunctions as hfns
 
+from twiggy import quick_setup,log
+quick_setup()
+logger = log.name('lossreserve')
+
 
 class LossReserve:
     """
@@ -558,7 +562,7 @@ class LossReserve:
             diagcml_ = self.predicted_Ipayments[-1,0]
             self.crmul_ay[self.predicted_Ipayments.shape[0]-1] = self.crmul_ay[self.predicted_Ipayments.shape[0]-1] + diagcml_
 
-        for ay in range(0,self.predicted_Ipayments.shape[0]-lr.tail): #add to the estimated random cumulative payments the upper triangle amounts
+        for ay in range(0,self.predicted_Ipayments.shape[0]-self.tail): #add to the estimated random cumulative payments the upper triangle amounts
             diagcml_=np.cumsum(self.predicted_Ipayments[ay,:(self.j-ay-1-self.tail+1)])[-1] #separate it to make it readable
             self.crmul_ay[ay]=self.crmul_ay[ay]+diagcml_
 
